@@ -327,7 +327,7 @@ def adaptive_format(num: numbers.Number, prev_value: Union[numbers.Number, Itera
             else:
                 return '{0:{1}}'.format(num, '.3e')
 
-    return '{0:{1}}'.format(num, format_string)
+        return '{0:{1}}'.format(num, format_string)
 
 
 def get_string_actual_length(input_string: str):
@@ -356,7 +356,7 @@ def PrintException():
 
     """
     exc_type, exc_obj, tb = sys.exc_info()
-
+    traceback.print_exception(*sys.exc_info())
     f = tb.tb_frame
     lineno = tb.tb_lineno
     filename = f.f_code.co_filename
@@ -635,7 +635,7 @@ class TensorShape(object):
     def numel(self):
         """Returns the total number of elements, or none for incomplete shapes."""
         if self.is_fully_defined():
-            return functools.reduce(operator.mul, self.to_list(), 1)
+            return functools.reduce(operator.mul, self.tolist(), 1)
         else:
             return None
 
@@ -850,7 +850,7 @@ class Signature(object):
         if completeness == 2:
             return False
         else:
-            True
+            return True
 
     def _get_kvsting(self, k, v):
         if v is None:
