@@ -817,3 +817,37 @@ class AdaptiveAvgPool2d(Layer):
 
         return F.adaptive_avg_pool2d(x, self.output_size)
 
+
+class Pooler(Layer):
+    """
+    Parameter-free poolers to get the sentence embedding
+    'cls': [CLS] representation with BERT/RoBERTa's MLP pooler.
+    'cls_before_pooler': [CLS] representation without the original MLP pooler.
+    'avg': average of the last layers' hidden states at each token.
+    'avg_top2': average of the last two layers.
+    'avg_first_last': average of the first and the last layers.
+    """
+    def __init__(self, pooler_type):
+        super().__init__()
+        self.pooler_type = pooler_type
+        assert self.pooler_type in ["cls","avg", "avg_top2", "avg_first_last"], "unrecognized pooling type %s" % self.pooler_type
+
+    def forward(self, x):
+        B,N,C=int_shape(x)
+        if self.pooler_type in [ 'cls']:
+            return  x[:,0,:]
+        elif self.pooler_type == "avg":
+            return reduce_mean(x,axis=1,keepdims=False)
+        elif self.pooler_type == "avg_first_last":
+            first_hidden = x[:,0,:]
+            last_hidden =  x[:,-1,:]
+            pooled_result = (first_hidden + last_hidden) / 2.0
+            return pooled_result
+        elif self.pooler_type == "avg_top2":
+            second_last_hidden =  x[:,-2,:]
+            last_hidden =  x[:,-1,:]
+            pooled_result = (last_hidden + second_last_hidden) / 2.0
+            return pooled_result
+        else:
+            raise NotImplementedError
+
