@@ -114,7 +114,7 @@ def SEResNet_IR(include_top=True,num_layers=50,Bottleneck=BottleNeck_IR_SE,drop_
 
 def SEResNet_IR_50_512(include_top=True,
              pretrained=True,
-             freeze_features=False,
+             freeze_features=True,
              input_shape=(3,112,112),
              classes=1000,
              **kwargs):
@@ -131,7 +131,7 @@ def SEResNet_IR_50_512(include_top=True,
         recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
         seresnet.model = recovery_model
     else:
-        seresnet.model = _make_recovery_model_include_top(seresnet.model, include_top=include_top, classes=classes, freeze_features=False)
+        seresnet.model = _make_recovery_model_include_top(seresnet.model, include_top=include_top, classes=classes, freeze_features=True)
     seresnet.model.input_shape = input_shape
     seresnet.model.to(_device)
     return seresnet
