@@ -126,7 +126,7 @@ def MobileNet( input_shape=(3, 224, 224), classes=1000, use_bias=False, width_mu
 
 def MobileNetV2(include_top=True,
              pretrained=True,
-             freeze_features=False,
+             freeze_features=True,
              input_shape=(3,224,224),
              classes=1000,
              **kwargs):
@@ -143,7 +143,7 @@ def MobileNetV2(include_top=True,
         mob.model = recovery_model
 
     else:
-        mob.model = _make_recovery_model_include_top(mob.model, include_top=include_top, classes=classes, freeze_features=False)
+        mob.model = _make_recovery_model_include_top(mob.model, include_top=include_top, classes=classes, freeze_features=True)
 
         mob.model.input_shape = input_shape
         mob.model.to(_device)
