@@ -122,7 +122,7 @@ def o_net():
 
 def Pnet(pretrained=True,
              input_shape=(3,12,12),
-             freeze_features=False,
+             freeze_features=True,
              **kwargs):
     if input_shape is not None and len(input_shape) == 3:
         input_shape = tuple(input_shape)
