@@ -216,7 +216,7 @@ def resnet18(include_top=True,
 
 def ResNet18(include_top=True,
              pretrained=True,
-             freeze_features=False,
+             freeze_features=True,
              input_shape=None,
              classes=1000,
              **kwargs):
@@ -233,7 +233,7 @@ def ResNet18(include_top=True,
         recovery_model = _make_recovery_model_include_top(recovery_model,input_shape=input_shape, include_top=include_top, classes=classes, freeze_features=freeze_features)
         resnet18.model = recovery_model
     else:
-        resnet18.model = _make_recovery_model_include_top(resnet18.model, include_top=include_top, classes=classes, freeze_features=False)
+        resnet18.model = _make_recovery_model_include_top(resnet18.model, include_top=include_top, classes=classes, freeze_features=True)
 
     resnet18.model.input_shape = input_shape
     resnet18.model.to(_device)
@@ -241,7 +241,7 @@ def ResNet18(include_top=True,
 
 def ResNet50(include_top=True,
              pretrained=True,
-             freeze_features=False,
+             freeze_features=True,
              input_shape=None,
              classes=1000,
              **kwargs):
@@ -258,7 +258,7 @@ def ResNet50(include_top=True,
         recovery_model = _make_recovery_model_include_top(recovery_model,input_shape=input_shape, include_top=include_top, classes=classes, freeze_features=freeze_features)
         resnet50.model = recovery_model
     else:
-        resnet50.model = _make_recovery_model_include_top(resnet50.model, include_top=include_top, classes=classes, freeze_features=False)
+        resnet50.model = _make_recovery_model_include_top(resnet50.model, include_top=include_top, classes=classes, freeze_features=True)
 
     resnet50.model.input_shape = input_shape
     resnet50.model.to(_device)
@@ -267,7 +267,7 @@ def ResNet50(include_top=True,
 
 def ResNet101(include_top=True,
              pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
              input_shape=None,
              classes=1000,
              **kwargs):
@@ -283,7 +283,7 @@ def ResNet101(include_top=True,
         recovery_model = _make_recovery_model_include_top(recovery_model,input_shape=input_shape, include_top=include_top, classes=classes, freeze_features=freeze_features)
         resnet101.model = recovery_model
     else:
-        resnet101.model = _make_recovery_model_include_top(resnet101.model, include_top=include_top, classes=classes, freeze_features=False)
+        resnet101.model = _make_recovery_model_include_top(resnet101.model, include_top=include_top, classes=classes, freeze_features=True)
 
     resnet101.model.input_shape = input_shape
     resnet101.model.to(_device)
@@ -292,7 +292,7 @@ def ResNet101(include_top=True,
 
 def ResNet152(include_top=True,
              pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
              input_shape=None,
              classes=1000,
              **kwargs):
@@ -308,7 +308,7 @@ def ResNet152(include_top=True,
         recovery_model = _make_recovery_model_include_top(recovery_model,input_shape=input_shape, include_top=include_top, classes=classes, freeze_features=freeze_features)
         resnet152.model = recovery_model
     else:
-        resnet152.model = _make_recovery_model_include_top(resnet152.model, include_top=include_top, classes=classes, freeze_features=False)
+        resnet152.model = _make_recovery_model_include_top(resnet152.model, include_top=include_top, classes=classes, freeze_features=True)
 
     resnet152.model.input_shape = input_shape
     resnet152.model.to(_device)
