@@ -162,7 +162,7 @@ def SE_ResNet(block, layers, input_shape=(3, 224, 224), num_classes=1000, use_bi
 
 def SE_ResNet50(include_top=True,
              pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
              input_shape=None,
              classes=1000,
              **kwargs):
@@ -179,7 +179,7 @@ def SE_ResNet50(include_top=True,
         recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
         resnet50.model = recovery_model
     else:
-        resnet50.model = _make_recovery_model_include_top(resnet50.model, include_top=include_top, classes=classes, freeze_features=False)
+        resnet50.model = _make_recovery_model_include_top(resnet50.model, include_top=include_top, classes=classes, freeze_features=True)
 
     resnet50.model.input_shape = input_shape
     resnet50.model.to(_device)
@@ -187,7 +187,7 @@ def SE_ResNet50(include_top=True,
 
 def SE_ResNet101(include_top=True,
              pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
              input_shape=None,
              classes=1000,
              **kwargs):
@@ -204,7 +204,7 @@ def SE_ResNet101(include_top=True,
         recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
         resnet101.model = recovery_model
     else:
-        resnet101.model = _make_recovery_model_include_top(resnet101.model, include_top=include_top, classes=classes, freeze_features=False)
+        resnet101.model = _make_recovery_model_include_top(resnet101.model, include_top=include_top, classes=classes, freeze_features=True)
 
     resnet101.model.input_shape = input_shape
     resnet101.model.to(_device)
@@ -213,7 +213,7 @@ def SE_ResNet101(include_top=True,
 
 def SE_ResNet152(include_top=True,
              pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
              input_shape=None,
              classes=1000,
              **kwargs):
@@ -230,7 +230,7 @@ def SE_ResNet152(include_top=True,
         recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
         resnet152.model = recovery_model
     else:
-        resnet152.model = _make_recovery_model_include_top(resnet152.model, include_top=include_top, classes=classes, freeze_features=False)
+        resnet152.model = _make_recovery_model_include_top(resnet152.model, include_top=include_top, classes=classes, freeze_features=True)
 
     resnet152.model.input_shape = input_shape
     resnet152.model.to(_device)
