@@ -525,7 +525,7 @@ class YoloDetectionModel(ImageDetectionModel):
 
 
 def YoLoV4(pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
             input_shape=(3, 608, 608),
              classes=80,
              **kwargs):
