@@ -201,7 +201,7 @@ def EfficientNet(width_coefficient,
 
 def EfficientNetB0(include_top=True,
              pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
              input_shape=(224,224,3),
              classes=1000,
              **kwargs):
@@ -219,7 +219,7 @@ def EfficientNetB0(include_top=True,
             recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
             effb0.model = recovery_model
         else:
-            effb0.model = _make_recovery_model_include_top(effb0.model, include_top=include_top, classes=classes, freeze_features=False)
+            effb0.model = _make_recovery_model_include_top(effb0.model, include_top=include_top, classes=classes, freeze_features=True)
 
         effb0.model.input_shape = input_shape
         effb0.model.name='efficientnet-b0'
@@ -228,7 +228,7 @@ def EfficientNetB0(include_top=True,
 
 def EfficientNetB1(include_top=True,
              pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
              input_shape=(240,240,3),
              classes=1000,
              **kwargs):
@@ -246,7 +246,7 @@ def EfficientNetB1(include_top=True,
             recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
             effb1.model = recovery_model
         else:
-            effb1.model = _make_recovery_model_include_top(effb1.model, include_top=include_top, classes=classes, freeze_features=False)
+            effb1.model = _make_recovery_model_include_top(effb1.model, include_top=include_top, classes=classes, freeze_features=True)
 
         effb1.model.input_shape = input_shape
         effb1.model.name = 'efficientnet-b1'
@@ -255,7 +255,7 @@ def EfficientNetB1(include_top=True,
 
 def EfficientNetB2(include_top=True,
              pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
              input_shape=(260,260,3),
              classes=1000,
              **kwargs):
@@ -273,7 +273,7 @@ def EfficientNetB2(include_top=True,
             recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
             effb2.model = recovery_model
         else:
-            effb2.model = _make_recovery_model_include_top(effb2.model, include_top=include_top, classes=classes, freeze_features=False)
+            effb2.model = _make_recovery_model_include_top(effb2.model, include_top=include_top, classes=classes, freeze_features=True)
 
         effb2.model.input_shape = input_shape
         effb2.model.name = 'efficientnet-b2'
@@ -282,7 +282,7 @@ def EfficientNetB2(include_top=True,
 
 def EfficientNetB3(include_top=True,
              pretrained=True,
-             freeze_features=False,
+             freeze_features=True,
              input_shape=(300,300,3),
              classes=1000,
              **kwargs):
@@ -300,7 +300,7 @@ def EfficientNetB3(include_top=True,
             recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
             effb3.model = recovery_model
         else:
-            effb3.model = _make_recovery_model_include_top(effb3.model, include_top=include_top, classes=classes, freeze_features=False)
+            effb3.model = _make_recovery_model_include_top(effb3.model, include_top=include_top, classes=classes, freeze_features=True)
 
         effb3.model.input_shape = input_shape
         effb3.model.name = 'efficientnet-b3'
@@ -309,7 +309,7 @@ def EfficientNetB3(include_top=True,
 
 def EfficientNetB4(include_top=True,
              pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
              input_shape=(380,380,3),
              classes=1000,
              **kwargs):
@@ -327,7 +327,7 @@ def EfficientNetB4(include_top=True,
             recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
             effb4.model = recovery_model
         else:
-            effb4.model = _make_recovery_model_include_top(effb4.model, include_top=include_top, classes=classes, freeze_features=False)
+            effb4.model = _make_recovery_model_include_top(effb4.model, include_top=include_top, classes=classes, freeze_features=True)
 
         effb4.model.input_shape = input_shape
         effb4.model.name = 'efficientnet-b4'
@@ -336,7 +336,7 @@ def EfficientNetB4(include_top=True,
 
 def EfficientNetB5(include_top=True,
              pretrained=True,
-             freeze_features=False,
+             freeze_features=True,
              input_shape=(456,456,3),
              classes=1000,
              **kwargs):
@@ -367,7 +367,7 @@ def EfficientNetB5(include_top=True,
             recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
             effb5.model = recovery_model
         else:
-            effb5.model = _make_recovery_model_include_top(effb5.model, include_top=include_top, classes=classes, freeze_features=False)
+            effb5.model = _make_recovery_model_include_top(effb5.model, include_top=include_top, classes=classes, freeze_features=True)
 
         effb5.model.input_shape = input_shape
         effb5.model.name = 'efficientnet-b5'
@@ -377,7 +377,7 @@ def EfficientNetB5(include_top=True,
 
 def EfficientNetB6(include_top=True,
              pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
              input_shape=(528,528,3),
              classes=1000,
              **kwargs):
@@ -395,7 +395,7 @@ def EfficientNetB6(include_top=True,
             recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
             effb6.model = recovery_model
         else:
-            effb6.model = _make_recovery_model_include_top(effb6.model, include_top=include_top, classes=classes, freeze_features=False)
+            effb6.model = _make_recovery_model_include_top(effb6.model, include_top=include_top, classes=classes, freeze_features=True)
 
         effb6.model.input_shape = input_shape
         effb6.model.name = 'efficientnet-b6'
@@ -405,7 +405,7 @@ def EfficientNetB6(include_top=True,
 
 def EfficientNetB7(include_top=True,
              pretrained=True,
-             freeze_features=False,
+             freeze_features=True,
              input_shape=(600,600,3),
              classes=1000,
              **kwargs):
@@ -423,7 +423,7 @@ def EfficientNetB7(include_top=True,
             recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
             effb7.model = recovery_model
         else:
-            effb7.model = _make_recovery_model_include_top(effb7.model, include_top=include_top, classes=classes, freeze_features=False)
+            effb7.model = _make_recovery_model_include_top(effb7.model, include_top=include_top, classes=classes, freeze_features=True)
 
         effb7.model.input_shape = input_shape
         effb7.model.name = 'efficientnet-b7'
