@@ -147,7 +147,7 @@ def ResNet(block, layers, input_shape=(224, 224,3), num_classes=1000, use_bias=F
 
 def ResNet18(include_top=True,
              pretrained=True,
-             freeze_features=False,
+             freeze_features=True,
              input_shape=None,
              classes=1000,
              **kwargs):
@@ -165,7 +165,7 @@ def ResNet18(include_top=True,
             recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
             resnet18.model = recovery_model
         else:
-            resnet18.model = _make_recovery_model_include_top(resnet18.model, include_top=include_top, classes=classes, freeze_features=False)
+            resnet18.model = _make_recovery_model_include_top(resnet18.model, include_top=include_top, classes=classes, freeze_features=True)
 
         resnet18.model.input_shape = input_shape
     return resnet18
@@ -173,7 +173,7 @@ def ResNet18(include_top=True,
 
 def ResNet50(include_top=True,
              pretrained=True,
-             freeze_features=False,
+             freeze_features=True,
              input_shape=None,
              classes=1000,
              **kwargs):
@@ -190,14 +190,14 @@ def ResNet50(include_top=True,
             recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
             resnet50.model = recovery_model
         else:
-            resnet50.model = _make_recovery_model_include_top(resnet50.model, include_top=include_top, classes=classes, freeze_features=False)
+            resnet50.model = _make_recovery_model_include_top(resnet50.model, include_top=include_top, classes=classes, freeze_features=True)
 
         resnet50.model.input_shape = input_shape
         return resnet50
 
 def ResNet101(include_top=True,
              pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
              input_shape=None,
              classes=1000,
              **kwargs):
@@ -214,7 +214,7 @@ def ResNet101(include_top=True,
             recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
             resnet101.model = recovery_model
         else:
-            resnet101.model = _make_recovery_model_include_top(resnet101.model, include_top=include_top, classes=classes, freeze_features=False)
+            resnet101.model = _make_recovery_model_include_top(resnet101.model, include_top=include_top, classes=classes, freeze_features=True)
 
         resnet101.model.input_shape = input_shape
         return resnet101
@@ -222,7 +222,7 @@ def ResNet101(include_top=True,
 
 def ResNet152(include_top=True,
              pretrained=True,
-            freeze_features=False,
+            freeze_features=True,
              input_shape=None,
              classes=1000,
              **kwargs):
@@ -239,7 +239,7 @@ def ResNet152(include_top=True,
             recovery_model = _make_recovery_model_include_top(recovery_model, include_top=include_top, classes=classes, freeze_features=freeze_features)
             resnet152.model = recovery_model
         else:
-            resnet152.model = _make_recovery_model_include_top(resnet152.model, include_top=include_top, classes=classes, freeze_features=False)
+            resnet152.model = _make_recovery_model_include_top(resnet152.model, include_top=include_top, classes=classes, freeze_features=True)
 
         resnet152.model.input_shape = input_shape
         return resnet152
