@@ -1035,7 +1035,7 @@ class Ranger(Optimizer):
     https://github.com/lessw2020/Ranger-Deep-Learning-Optimizer/blob/master/ranger/ranger.py
     """
 
-    def __init__(self, params, lr=1e-3, alpha=0.5, k=6, N_sma_threshhold=5, betas=(.95, 0.999), eps=1e-7,
+    def __init__(self, params, lr=1e-3, alpha=0.5, k=6, N_sma_threshhold=5, betas=(.95, 0.999), eps=1e-5,
                  weight_decay=0, gradient_centralization=None):
         self.gradient_centralization = gradient_centralization
         # parameter checks
@@ -1057,7 +1057,7 @@ class Ranger(Optimizer):
         # prep defaults and init torch.optim base
         defaults = dict(lr=lr, alpha=alpha, k=k, step_counter=0, betas=betas,
                         N_sma_threshhold=N_sma_threshhold, eps=eps,
-                        weight_decay=weight_decay)
+                        weight_decay=weight_decay, gradient_centralization=gradient_centralization)
         super().__init__(params, defaults)
 
         # adjustable threshold
@@ -1113,30 +1113,34 @@ class Ranger(Optimizer):
             for p in group['params']:
                 if p.grad is None or not p.requires_grad:
                     continue
-                grad = p.grad.data
+
+                grad = p.grad.data.float()
 
                 if grad.is_sparse:
                     raise RuntimeError('Ranger optimizer does not support sparse gradients')
 
-                p_data = p.data
+                # p_data = p.data
+                p_data_fp32 = p.data.float()
 
                 state = self.state[p]  # get state dict for this param
 
                 if len(state) == 0:  # if first time to run...init dictionary with our desired entries
                     state['step'] = 0.0
-                    state['exp_avg'] = torch.zeros_like(p_data, memory_format=torch.preserve_format)
-                    state['exp_avg_sq'] = torch.zeros_like(p_data, memory_format=torch.preserve_format)
+                    state['exp_avg'] = torch.zeros_like(p_data_fp32)
+                    state['exp_avg_sq'] = torch.zeros_like(p_data_fp32)
 
                     # look ahead weight storage now in state dict
-                    state['slow_buffer'] = torch.empty_like(p.data)
-                    state['slow_buffer'].copy_(p.data)
+                    state['slow_buffer'] = torch.empty_like(p_data_fp32)
+                    state['slow_buffer'].copy_(p_data_fp32)
                 else:
-                    state['exp_avg'] = state['exp_avg'].type_as(p_data)
-                    state['exp_avg_sq'] = state['exp_avg_sq'].type_as(p_data)
+                    state['exp_avg'] = state['exp_avg'].type_as(p_data_fp32)
+                    state['exp_avg_sq'] = state['exp_avg_sq'].type_as(p_data_fp32)
 
                 # begin computations
                 exp_avg, exp_avg_sq = state['exp_avg'], state['exp_avg_sq']
                 beta1, beta2 = group['betas']
+                state['step'] += 1.0
+
                 if self.gradient_centralization in ['all', 'gcc']:
                     if len(list(grad.size())) > 3:
                         grad.add_(-grad.mean(dim=tuple(range(1, grad.dim())), keepdim=True))
@@ -1145,8 +1149,8 @@ class Ranger(Optimizer):
 
                 exp_avg_sq.mul_(beta2).addcmul_(grad, grad, value=1 - beta2)
 
-                state['step'] += 1.0
                 buffered = self.radam_buffer[int(state['step'] % 10)]
+
                 if state['step'] == buffered[0]:
                     N_sma, step_size = buffered[1], buffered[2]
                 else:
@@ -1155,43 +1159,44 @@ class Ranger(Optimizer):
                     N_sma_max = 2 / (1 - beta2) - 1
                     N_sma = N_sma_max - 2 * state['step'] * beta2_t / (1 - beta2_t)
                     buffered[1] = N_sma
-
-                    # more conservative since it's an approximated value
-                    if N_sma >= self.N_sma_threshhold:
-                        step_size = math.sqrt((1 - beta2_t) * (N_sma - 4) / (N_sma_max - 4) * (N_sma - 2) / N_sma * N_sma_max / (
-                                N_sma_max - 2)) / (1 - beta1 ** state['step'])
+                    if N_sma > self.N_sma_threshhold:
+                        step_size = math.sqrt((1 - beta2_t) * (N_sma - 4) / (N_sma_max - 4) * (
+                                N_sma - 2) / N_sma * N_sma_max / (N_sma_max - 2)) / (1 - beta1 ** state['step'])
                     else:
                         step_size = 1.0 / (1 - beta1 ** state['step'])
                     buffered[2] = step_size
 
                 if group['weight_decay'] != 0:
-                    grad = grad.add(p, alpha=group['weight_decay'])
+                    p_data_fp32.add_(-group['weight_decay'] * group['lr'], p_data_fp32)
 
                 if self.gradient_centralization in ['all', 'gc']:
                     if len(list(grad.size())) > 1:
                         grad.add_(-grad.mean(dim=tuple(range(1, len(list(grad.size())))), keepdim=True))
 
-                if N_sma > 5:
+                if N_sma > self.N_sma_threshhold:
                     denom = exp_avg_sq.sqrt().add_(group['eps'])
-                    p_data.addcdiv_(exp_avg, denom, value=-step_size * group['lr'])
+                    p_data_fp32.addcdiv_(-step_size * group['lr'], exp_avg, denom)
                 else:
-                    p_data.add_(exp_avg, alpha=-step_size * group['lr'])
+                    p_data_fp32.add_(-step_size * group['lr'], exp_avg)
 
-                if any_abnormal_number(p_data):
+                if any_abnormal_number(p_data_fp32):
                     sys.stderr.write('{0} p_data has abnormal value,trident automatically replace these abnormal value to zero.\n\r'.format(self.__class__.__name__))
-                    p_data = where(is_abnormal_number(p_data), p.data, p_data)
+                    p_data = where(is_abnormal_number(p_data_fp32), p.data, p_data_fp32)
 
-                p.data.copy_(p_data)
 
+                p.data.copy_(p_data_fp32)
                 # integrated look ahead...
                 # we do it at the param level instead of group level
                 if state['step'] % group['k'] == 0:
-                    slow_p = state['slow_buffer']  # get access to slow param tensor
-                    slow_p.add_(p.data - slow_p, alpha=self.alpha)  # (fast weights - slow weights) * alpha
+                    # get access to slow param tensor
+                    slow_p = state['slow_buffer']
+                    # (fast weights - slow weights) * alpha
+                    slow_p.add_(self.alpha, p.data - slow_p)
                     if any_abnormal_number(slow_p):
                         sys.stderr.write('{0} p_data has abnormal value,trident automatically replace these abnormal value to zero.\n'.format(self.__class__.__name__))
                         slow_p = where(is_abnormal_number(slow_p), p.data, slow_p)
-                    p.data.copy_(slow_p)  # copy interpolated weights to RAdam param tensor
+                    # copy interpolated weights to RAdam param tensor
+                    p.data.copy_(slow_p)
 
         return loss
 
