@@ -30,7 +30,7 @@ from trident.callbacks.visualization_callbacks import *
 from trident.data.data_provider import *
 from trident.misc.ipython_utils import *
 from trident.misc.visualization_utils import tile_rgb_images, loss_metric_curve
-from trident.backend.tensorspec import TensorSpec, assert_spec_compatibility
+from trident.backend.tensorspec import TensorSpec, assert_spec_compatibility,get_signature
 from trident.loggers.history import HistoryBase
 
 __all__ = ['TrainingPlan', 'GanTrainingPlan']
@@ -386,6 +386,8 @@ class TrainingPlan(object):
             existing_data_feed = None
             if 'data_feed' in trainingitem.training_context:
                 existing_data_feed = trainingitem.training_context['data_feed']
+            if not hasattr(trainingitem._model,'_signature') or  trainingitem._model._signature is None:
+                trainingitem._model._signature=get_signature(trainingitem._model)
 
             data_feed = OrderedDict()
             # datasets = data_provider.traindata.get_datasets()
@@ -403,12 +405,16 @@ class TrainingPlan(object):
                 for inp in v.signature.inputs.key_list:
                     data_feed[inp] = None
 
-            if ('x' in data_feed or 'input' in data_feed) and 'input' in available_items:
-                if 'x' in data_feed:
-                    data_feed['x'] = 'input'
-                    available_items.remove('input')
-                elif 'input' in data_feed:
-                    data_feed['input'] = 'input'
+            if 'x' in data_feed :
+                if len(data_symbols)==1 and  data_symbols[0] in available_items:
+                    data_feed['x'] = data_symbols[0]
+                    available_items.remove(data_symbols[0] )
+
+                if 'x' in available_items:
+                    data_feed['x'] ='x'
+                    available_items.remove('x')
+                elif 'input' in available_items:
+                    data_feed['x'] ='input'
                     available_items.remove('input')
 
             if len(trainingitem.signature.inputs) == len(data_symbols) == 1:
@@ -445,9 +451,23 @@ class TrainingPlan(object):
             print('data_feed for {0} :'.format(trainingitem.name))
             print(json.dumps(data_feed, indent=4, sort_keys=True))
 
+    def do_on_training_start(self):
+        for callback in self.callbacks:
+            callback.on_training_start(self.__dict__)
+        for item in self.training_items.value_list:
+            item.train()
+
+
+    def do_on_training_end(self):
+        for callback in self.callbacks:
+            callback.on_training_end(self.__dict__)
+        for item in self.training_items.value_list:
+            item.save_model()
+            item.eval()
 
     def start_now(self, collect_data_inteval=1, is_resume=False, only_steps=False, max_batches=np.inf,
                   keep_weights_history=False, keep_gradient_history=False):
+
         data_provider = self._dataloaders.value_list[0]
         data_provider.batch_size = self.batch_size
         data_provider.mode = 'dict'
@@ -502,6 +522,7 @@ class TrainingPlan(object):
 
             if len(data_provider._batch_transform_funcs) > 0:
                 data_provider.traindata.batch_sampler._batch_transform_funcs = data_provider._batch_transform_funcs
+            self.do_on_training_start()
             for epoch in range(self.num_epochs):
                 try:
                     for mbs, return_data in enumerate(data_provider):
@@ -560,24 +581,22 @@ class TrainingPlan(object):
                                 start_epoch=0 if not hasattr(trainitem,'start_epoch') else trainitem.start_epoch
                                 if epoch <start_epoch:
                                     trainitem.training_context['stop_update'] = 1
-
+                                num_epoch=self.num_epochs if only_steps == False else 1
                                 num_batches=len(data_provider.batch_sampler) if only_steps == False else max_batches
                                 current_batch=mbs if only_steps == False else self.steps
                                 current_epoch=epoch if only_steps == False else 0
                                 if current_batch ==0:
-                                    if current_epoch==0:
-                                        trainitem.do_on_training_start()
                                     trainitem.do_on_epoch_start()
                                 trainitem.steps=self.steps
                                 trainitem.current_epoch=current_epoch
                                 trainitem.current_batch=current_batch
                                 trainitem.train_model(train_data, test_data,
-                                                      epoch if only_steps == False else 0,
-                                                      mbs if only_steps == False else self.steps,
-                                                      self.num_epochs if only_steps == False else 1,
+                                                      current_epoch,
+                                                      current_batch,
+                                                      num_epoch,
                                                       num_batches,
                                                       done=None,
-                                                      is_collect_data=mbs == 0 or mbs % collect_data_inteval == 0,
+                                                      is_collect_data=current_batch == 0 or current_batch % collect_data_inteval == 0,
                                                       is_print_batch_progress=self.print_progress_unit == 'batch' and mbs > 0 and mbs % self.print_progress_frequency == 0,
                                                       is_print_epoch_progress=self.print_progress_unit == 'epoch' and epoch > 0 and epoch % self.print_progress_frequency == 0,
                                                       log_gradients=keep_gradient_history, log_weights=keep_weights_history,
@@ -648,18 +667,18 @@ class TrainingPlan(object):
                     print(ve)
                     PrintException()
                     for k, trainitem in self.training_items.items():
-                        trainitem.do_on_training_end()
-                        trainitem.save_model(trainitem.training_context['save_path'], )
+                        trainitem.do_on_excution_exception()
+
                 except Exception as e:
                     print(e)
                     PrintException()
                     for k, trainitem in self.training_items.items():
-                        trainitem.do_on_training_end()
-                        trainitem.save_model(trainitem.training_context['save_path'], )
+                        trainitem.do_on_excution_exception()
                 if self.save_model_frequency > 0 and self.save_model_unit == 'epoch' and (
                         epoch + 1) % self.save_model_frequency == 0:
                     for k, trainitem in self.training_items.items():
                         trainitem.save_model(trainitem.training_context['save_path'], )
+            self.do_on_training_end()
             data_provider.mode = 'tuple'
 
 
@@ -1325,14 +1344,13 @@ class GanTrainingPlan(TrainingPlan):
                     print(ve)
                     PrintException()
                     for k, trainitem in self.training_items.items():
-                        trainitem.do_on_training_end()
-                        trainitem.save_model(trainitem.training_context['save_path'], )
+                        trainitem.do_on_excution_exception()
                 except Exception as e:
                     print(e)
                     PrintException()
                     for k, trainitem in self.training_items.items():
-                        trainitem.do_on_training_end()
-                        trainitem.save_model(trainitem.training_context['save_path'], )
+                        trainitem.do_on_excution_exception()
+
                 if self.save_model_frequency > 0 and self.save_model_unit == 'epoch' and (
                         epoch + 1) % self.save_model_frequency == 0:
                     for k, trainitem in self.training_items.items():
